@@ -12,6 +12,7 @@ __maintainer__ = "Ricardo Ribeiro"
 __email__ = "ricardojvr@gmail.com"
 __status__ = "Development"
 
+import codetiming
 import logging, os, math
 from AnyQt.QtWidgets import QStyle
 from .multiple_videocapture import MultipleVideoCapture
@@ -277,6 +278,79 @@ class ControlPlayer(ControlBase, QFrame):
         self.next_frame_step = 9
         self.video_widget.show_tmp_msg('Speed: 9x')
 
+    def set_speed_10x(self):
+        """
+        Set video playing speed 9x.
+        :return:
+        """
+        self.next_frame_step = 10
+        self.video_widget.show_tmp_msg('Speed: 10x')
+
+    def set_speed_20x(self):
+        """
+        Set video playing speed 9x.
+        :return:
+        """
+        self.next_frame_step = 20
+        self.video_widget.show_tmp_msg('Speed: 20x')
+
+    def set_speed_30x(self):
+        """
+        Set video playing speed 9x.
+        :return:
+        """
+        self.next_frame_step = 30
+        self.video_widget.show_tmp_msg('Speed: 30x')
+
+    def set_speed_40x(self):
+        """
+        Set video playing speed 9x.
+        :return:
+        """
+        self.next_frame_step = 40
+        self.video_widget.show_tmp_msg('Speed: 40x')
+
+    def set_speed_50x(self):
+        """
+        Set video playing speed 9x.
+        :return:
+        """
+        self.next_frame_step = 50
+        self.video_widget.show_tmp_msg('Speed: 50x')
+
+    def set_speed_60x(self):
+        """
+        Set video playing speed 9x.
+        :return:
+        """
+        self.next_frame_step = 60
+        self.video_widget.show_tmp_msg('Speed: 60x')
+
+    def set_speed_70x(self):
+        """
+        Set video playing speed 9x.
+        :return:
+        """
+        self.next_frame_step = 70
+        self.video_widget.show_tmp_msg('Speed: 70x')
+
+    def set_speed_80x(self):
+        """
+        Set video playing speed 9x.
+        :return:
+        """
+        self.next_frame_step = 80
+        self.video_widget.show_tmp_msg('Speed: 80x')
+
+    def set_speed_90x(self):
+        """
+        Set video playing speed 90x.
+        :return:
+        """
+        self.next_frame_step = 90
+        self.video_widget.show_tmp_msg('Speed: 90x')
+
+
     ##########################################################################
     ############ EVENTS ######################################################
     ##########################################################################
@@ -355,7 +429,7 @@ class ControlPlayer(ControlBase, QFrame):
             return 0
 
         # This self._value. query is OK
-        return int(self._value.get(7))
+        return int(self._value.get(TOTAL_NUMBER_OF_FRAMES))
 
     @property
     def frame(self): return self._current_frame
@@ -508,8 +582,9 @@ class ControlPlayer(ControlBase, QFrame):
             return
 
         # read next frame
-        (success, self._current_frame) = self.value.read()
-
+        with codetiming.Timer(text="self.value.read took {:.8f} seconds", logger=logger.debug):
+            (success, self._current_frame) = self.value.read()
+ 
         # increment frame index if the step is bigger than 1
         if increment_frame and self.next_frame_step > 1:
             self.video_index += self.next_frame_step
@@ -575,6 +650,7 @@ class ControlPlayer(ControlBase, QFrame):
             self.play()
 
     def convertFrameToTime(self, totalMilliseconds):
+        # totalMilliseconds = totalMilliseconds*(1000.0/self._value.get(5))
         if math.isnan(totalMilliseconds): return 0, 0, 0
         totalseconds = int(totalMilliseconds / 1000)
         minutes = int(totalseconds / 60)
@@ -582,13 +658,22 @@ class ControlPlayer(ControlBase, QFrame):
         milliseconds = totalMilliseconds - (totalseconds * 1000)
         return (minutes, seconds, milliseconds)
 
-    def videoProgress_valueChanged(self):
-        # This self._value. query is OK
-        milli = self._value.get(0)
-        (minutes, seconds, milliseconds) = self.convertFrameToTime(milli)
-        self.videoTime.setText(
-            "%02d:%02d:%03d" % (minutes, seconds, milliseconds))
 
+    def convertFrameToHours(self, totalMilliseconds):
+        if math.isnan(totalMilliseconds): return 0, 0, 0
+        hours = totalMilliseconds / 1000 / 3600
+        return hours
+
+        
+    def videoProgress_valueChanged(self):
+        milli = self._value.get(0)
+        if conf.TIME_FORMAT == "MSM":
+            (minutes, seconds, milliseconds) = self.convertFrameToTime(milli)
+            self.videoTime.setText(
+                "%02d:%02d:%03d" % (minutes, seconds, milliseconds))
+        elif conf.TIME_FORMAT == "H":
+            hours = self.convertFrameToHours(milli)
+            self.videoTime.setText(f"{round(hours, 2)} H")     
 
 
     def videoProgress_sliderReleased(self):
